AgentServerBuilder

Struct AgentServerBuilder 

pub struct AgentServerBuilder<'a> { /* private fields */ }
Builder for configuring and launching an AgentServer. Builder for creating an AgentServer.

Implementations

Source

impl<'a> AgentServerBuilder<'a>

pub fn new( port: u16, provider: Providers, system_message: &'a str, model: &'a str, ) -> Self

Creates a new AgentServerBuilder with the given port, provider, system message, and model.

pub fn api_key(self, api_key: &'a str) -> Self

Sets the API key for the provider.

pub fn temperature(self, temperature: f64) -> Self

Sets the temperature for the provider.

pub fn max_tokens(self, max_tokens: u64) -> Self

Sets the maximum number of tokens for the provider.

pub fn build(self) -> Result<AgentServer, Error>

Builds the AgentServer with the given configuration.

pub fn build_with_schema<J: JsonSchema>(self) -> Result<AgentServer, Error>

Builds the AgentServer with the given configuration and schema.

pub fn build_with_tool<T: Tool + 'static>( self, tool: ToolWrapper<T>, ) -> Result<AgentServer, Error>

Builds the AgentServer with the given configuration and tool.