ToolWrapper

Struct ToolWrapper 

pub struct ToolWrapper<T: Tool + 'static>(/* private fields */);
Wrapper type for integrating tools into the agent server. A wrapper around a Tool that implements Clone.

Implementations

Source

impl<T: Tool + 'static> ToolWrapper<T>

pub fn new(tool: T) -> Self

Creates a new ToolWrapper with the given struct that implements the Tool trait.

example:

use rpc_agent::tools::ToolWrapper;
use rig::tool::Tool;

struct MyTool;

impl Tool for MyTool {
    const NAME: &'static str = "my_tool";
    type Error = anyhow::Error;
    type Args = Input;
    type Output = u32;

    async fn definition(&self, _prompt: String) -> rig::completion::ToolDefinition {
        ToolDefinition {
            name: "get_ticket_price".to_string(),
            description: "Get the price of a return ticket to the destination city.".to_string(),
            parameters: serde_json::json!({
                "type": "object",
                "properties": {
                    "destination_city": {
                        "type": "string",
                        "description": "The destination city"
                    }
                },
                "required": ["destination_city"],
            }),
        }
    }

    async fn call(&self, _args: Self::Args) -> Result<Self::Output, Self::Error> {
        println!("Tools called for {}", &args.destination_city);
        let result = Self::get_ticket_price(&args.destination_city)?;
        Ok(result)
    }
}

let tool = ToolWrapper::new(MyTool);